Semantic

Enum Semantic 

pub enum Semantic {
Show 24 variants Binormal, Color, Continuity, Image, Input, InTangent, Interpolation, InvBindMatrix, Joint, LinearSteps, MorphTarget, MorphWeight, Normal, Output, OutTangent, Position, Tangent, TexBinormal, TexCoord, TexTangent, UV, Vertex, Weight, Other(Box<str>),
}
An Input semantic attribute. Common / defined values are pre-parsed, and the remainder are in the Other variant.

Variants



Binormal

Geometric binormal (bitangent) vector



Color

Color coordinate vector. Color inputs are RGB (float3)



Continuity

Continuity constraint at the control vertex (CV)



Image

Raster or MIP-level input



Input

Sampler input



InTangent

Tangent vector for preceding control point



Interpolation

Sampler interpolation type



InvBindMatrix

Inverse of local-to-world matrix



Joint

Skin influence identifier



LinearSteps

Number of piece-wise linear approximation steps to use for the spline segment that follows this CV



MorphTarget

Morph targets for mesh morphing



MorphWeight

Weights for mesh morphing



Normal

Normal vector



Output

Sampler output



OutTangent

Tangent vector for succeeding control point



Position

Geometric coordinate vector



Tangent

Geometric tangent vector



TexBinormal

Texture binormal (bitangent) vector



TexCoord

Texture coordinate vector



TexTangent

Texture coordinate vector



UV

Generic parameter vector



Vertex

Mesh vertex



Weight

Skin influence weighting value



Other(Box<str>)

Any value not covered above