SurfaceChannels

Enum SurfaceChannels 

pub enum SurfaceChannels {
    RGB,
    RGBA,
    L,
    LA,
    D,
    XYZ,
    XYZW,
}
The per-texel layout of the format. The length of the enumeration string indicates how many channels there are and each letter represents the name of a channel. There are typically 1 to 4 channels.

Variants



RGB

Red/Green/Blue color map.



RGBA

Red/Green/Blue/Alpha map, often used for color and transparency or other things packed into channel A, such as specular power.



L

Luminance map, often used for light mapping.



LA

Luminance/Alpha map, often used for light mapping.



D

Depth map, often used for displacement, parallax, relief, or shadow mapping.



XYZ

Typically used for normal maps or three-component displacement maps.



XYZW

Typically used for normal maps, where W is the depth for relief or parallax mapping.

Implementations

Source

impl SurfaceChannels

pub fn to_str(self) -> &'static str

The XML name of a value in this enumeration.