pub enum SurfaceOption {
SrgbGamma,
Normalized3,
Normalized4,
Compressible,
}Expand description
Contains additional hints about data relationships and other things to help an application pick the best format.
Variants
SrgbGamma
Colors are stored with respect to the sRGB 2.2 gamma curve rather than linear.
Normalized3
The texel’s XYZ/RGB should be normalized such as in a normal map.
Normalized4
The texel’s XYZW/RGBA should be normalized such as in a normal map.
Compressible
The surface may use run-time compression.
Consider the best compression based on desired SurfaceChannels,
SurfaceRange, SurfacePrecision, and SurfaceOptions.
Implementations