Trait dae_parser::geom::UrlResolver[][src]

pub trait UrlResolver<'a, T> {
    type Error;
    fn resolve(&self, url: &UrlRef<T>) -> Result<&'a T, Self::Error>;
}
This trait abstracts over types that can be used to resolve URL references. It is implemented for LocalMap and LocalMaps, and user types can also implement this trait to provide external URL resolution.

Associated Types

The error type of the resolver.

Required methods

Resolve an individual URL.

Implementors