InputKind

Trait InputKind 

pub trait InputKind {
    type Array: ArrayKind;
    type Reader: SourceRead<Self>;

    // Required method
    fn new_reader(&self, acc: &Accessor) -> Option<Self::Reader>;
}
A trait implemented on marker types like XYZ to allow for strict typing of input kinds.

Required Associated Types

type Array: ArrayKind

The array type that this reader is expecting. Must be one of the types in ArrayElement.

type Reader: SourceRead<Self>

The associated reader type.

Required Methods

fn new_reader(&self, acc: &Accessor) -> Option<Self::Reader>

Constructs a new reader object from the given Accessor.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors