pub struct Geometry {
pub id: Option<String>,
pub name: Option<String>,
pub asset: Option<Box<Asset>>,
pub element: GeometryElement,
pub extra: Vec<Extra>,
}Expand description
Describes the visual shape and appearance of an object in a scene.
Fields
id: Option<String>A text string containing the unique identifier of the element.
name: Option<String>The text string name of this element.
asset: Option<Box<Asset>>Asset management information about this element.
element: GeometryElementThe element that describes geometric data.
extra: Vec<Extra>Provides arbitrary additional information about this element.
Implementations