Type Definition dae_parser::TriStrips[][src]

pub type TriStrips = Geom<TriStripGeom>;
Provides the information needed for a mesh to bind vertex attributes together and then organize those vertices into connected triangles.

Implementations

Construct a new TriStrips object from a data buffer. Each buffer in data contains 3 or more vertices, each consisting of inputs.len() indices, for a total of inputs.len() * verts values.