Module dae_parser::local_map [−][src]
Structs
A map for looking up elements of type T in the document by ID.
A data structure which maintains LocalMaps for every applicable type.
If you need to use Document::local_map for many different types,
it may be more efficient to use this type, which calculates all maps
in a single pass.
Traits
A generic ID getter function.
A trait for types that can be enumerated in a Document. This is used to power the
for_each and try_for_each functions.